==> 0ad-0.27.1-unix-build.tar.xz: 0ad-0.27.1/LICENSE.md <==
# 0 A.D. Licensing Details

0 A.D. and the Pyrogenesis engine are released as free and open source: you can freely use, copy,
modify and distribute the game's source code and data files, as long as you include
attribution to Wildfire Games and let anyone freely modify and distribute any
of your own modifications to the game's files.

The distribution includes several different types of files, and a number of
third-party components. The details are described here, based on the directory
structure. For any file, see the longest path name below which is a prefix of
the file's path.

If you have a question about, or can provide any information on missing or wrong licensing details,
please inform Wildfire Games at webmaster at wildfiregames dot com.

## Other Licenses based on the Directory Structure

- binaries/data/
  - GPL version 2 (or later) - see license_gpl-2.0.txt

- binaries/data/mods/*/art
- binaries/data/mods/*/audio
  - Creative Commons Attribution-Share Alike 3.0 - see
        http://creativecommons.org/licenses/by-sa/3.0/
        and also see LICENSE.txt within those directories

- binaries/data/mods/*/maps/
  - see LICENSE.txt within those directories

- binaries/data/mods/public/shaders/glsl/fxaa.fs
  - BSD

- binaries/data/mods/public/shaders/glsl/cas.fs
  - MIT

- binaries/system/
  - Various (unspecified)

- binaries/system/dbghelp.dll
  - Proprietary - see license_dbghelp.txt for restrictions you must agree to
      before distributing this particular file

- build/
  - Various (unspecified)

- build/arclint/
  - GPL version 2 (or later) - see license_gpl-2.0.txt

- build/arclint/pyrolint/
  - Apache version 2 - see license_apache2.txt within that directory

- build/premake/premake5/
  - BSD

- build/premake/*.lua
  - MIT - see license_mit.txt

- docs/
  - Various (unspecified)

- libraries/
  - Various - see LICENSE.txt within that directory

- source/
  - GPL version 2 (or later) - see license_gpl-2.0.txt

- source/lib/
  - MIT - see license_mit.txt

- source/scriptinterface/third_party/
  - MPL 2.0

- source/third_party/encryption/
  - GPL version 2 (or later)
  - ISC (pkcs5_pbkdf2.cpp)
  - MIT (pkcs5_pbkdf2.h) - see license_mit.txt

- source/third-party/jsonspirit/
  - MIT - see license_mit.txt

- source/third_party/mikktspace/
  - zlib

- source/third_party/mongoose/
  - MIT - see license_mit.txt

- source/third_party/tinygettext/
  - zlib

- source/third-party/vma/
  - MIT - see LICENSE.txt within that directory

- source/tools/
  - Various - see LICENSE.txt within that directory

- source/tools/atlas/
  - GPL version 2 (or later) - see license_gpl-2.0.txt

- binaries/data/mods/public/gui/prelobby/common/terms/  
  binaries/data/mods/public/gui/userreport/Terms_and_Conditions.txt  
  binaries/data/mods/mod/gui/modio/Disclaimer.txt
  - Redistributing modified Terms and Conditions of online services may be within the licensing,
    but may not change the legality or enforceability of the terms of the service provider.
    It may be against the terms of the service provider to use online services with modified terms.

==> 0ad-0.28.0-rc3-unix-build.tar.xz: 0ad-0.28.0/LICENSE.md <==
# 0 A.D. Licensing Details

0 A.D. and the Pyrogenesis engine are released as free and open source: you can freely use, copy,
modify and distribute the game's source code and data files, as long as you include
attribution to Wildfire Games and let anyone freely modify and distribute any
of your own modifications to the game's files.

The distribution includes several different types of files, and a number of
third-party components. The details are described here, based on the directory
structure. For any file, see the longest path name below which is a prefix of
the file's path.

If you have a question about, or can provide any information on missing or wrong licensing details,
please inform Wildfire Games at webmaster at wildfiregames dot com.

## Other Licenses based on the Directory Structure

- binaries/data/
  - GPL version 2 (or later) - see license_gpl-2.0.txt

- binaries/data/mods/*/art
- binaries/data/mods/*/audio
  - Creative Commons Attribution-Share Alike 3.0 - see
        http://creativecommons.org/licenses/by-sa/3.0/
        and also see LICENSE.txt within those directories

- binaries/data/mods/*/maps/
  - see LICENSE.txt within those directories

- binaries/data/mods/mod/shaders/glsl/fxaa.fs
  - BSD

- binaries/data/mods/mod/shaders/glsl/cas.fs
  - MIT

- binaries/system/
  - Various (unspecified)

- binaries/system/dbghelp.dll
  - Proprietary - see license_dbghelp.txt for restrictions you must agree to
      before distributing this particular file

- build/
  - Various (unspecified)

- build/arclint/
  - GPL version 2 (or later) - see license_gpl-2.0.txt

- build/arclint/pyrolint/
  - Apache version 2 - see license_apache2.txt within that directory

- build/premake/premake5/
  - BSD

- build/premake/*.lua
  - MIT - see license_mit.txt

- docs/
  - Various (unspecified)

- libraries/
  - Various - see LICENSE.txt within that directory

- source/
  - GPL version 2 (or later) - see license_gpl-2.0.txt

- source/lib/
  - MIT - see license_mit.txt

- source/scriptinterface/third_party/
  - MPL 2.0

- source/third_party/encryption/
  - GPL version 2 (or later)
  - ISC (pkcs5_pbkdf2.cpp)
  - MIT (pkcs5_pbkdf2.h) - see license_mit.txt

- source/third-party/jsonspirit/
  - MIT - see license_mit.txt

- source/third_party/mikktspace/
  - zlib

- source/third_party/mongoose/
  - MIT - see license_mit.txt

- source/third_party/tinygettext/
  - zlib

- source/third-party/vma/
  - MIT - see LICENSE.txt within that directory

- source/tools/
  - Various - see LICENSE.txt within that directory

- source/tools/atlas/
  - GPL version 2 (or later) - see license_gpl-2.0.txt

- binaries/data/mods/public/gui/prelobby/common/terms/
  binaries/data/mods/public/gui/userreport/Terms_and_Conditions.txt
  binaries/data/mods/mod/gui/modio/Disclaimer.txt
  - Redistributing modified Terms and Conditions of online services may be within the licensing,
    but may not change the legality or enforceability of the terms of the service provider.
    It may be against the terms of the service provider to use online services with modified terms.
